@@ -2,8 +2,11 @@
 This builder functions as a pseudo builder that instead downloads and installs a binary file using
 release-gitter based on a pyproject.toml file. It's a total hack...
 """
+from __future__ import annotations
+
 from pathlib import Path
 from shutil import copytree
+from shutil import move
 
 import toml
 from wheel.wheelfile import WheelFile
@@ -15,7 +18,7 @@ PACKAGE_NAME = "pseudo"
 
 
 def download(config) -> list[Path]:
-    release = rg.get_release(
+    release = rg.fetch_release(
         rg.GitRemoteInfo(config.hostname, config.owner, config.repo), config.version
     )
     asset = rg.match_asset(
@@ -54,7 +57,7 @@ def read_metadata():
         else:
             args = [key, value] + args
 
-    return rg.parse_args(args)
+    return rg._parse_args(args)
 
 
 class _PseudoBuildBackend:
@@ -123,13 +126,12 @@ class _PseudoBuildBackend:
         wheel_scripts = wheel_directory / f"{PACKAGE_NAME}-{version}.data/scripts"
         wheel_scripts.mkdir(parents=True, exist_ok=True)
 
-        # copytree(metadata_directory, wheel_directory / metadata_directory.name)
         copytree(metadata_directory, wheel_directory / metadata_directory.name)
 
         metadata = read_metadata()
         files = download(metadata)
         for file in files:
-            file.rename(wheel_scripts / file.name)
+            move(file, wheel_scripts / file.name)
 
         print(f"ls {wheel_directory}: {list(wheel_directory.glob('*'))}")
 
