@@ -1,4 +1,6 @@
 #! /usr/bin/env python3
+from __future__ import annotations
+
 import argparse
 import platform
 from collections.abc import Sequence
@@ -65,8 +67,8 @@ class GitRemoteInfo:
         )
 
 
-def get_git_remote(git_url: Optional[str] = None) -> GitRemoteInfo:
-    """Extract Github repo info from git remote url"""
+def parse_git_remote(git_url: Optional[str] = None) -> GitRemoteInfo:
+    """Extract Github repo info from a git remote url"""
     if not git_url:
         git_url = (
             check_output(["git", "remote", "get-url", "origin"]).decode("UTF-8").strip()
@@ -91,10 +93,17 @@ def get_git_remote(git_url: Optional[str] = None) -> GitRemoteInfo:
             f"{path[1:3]} Could not parse owner and repo from URL {git_url}"
         )
 
-    return GitRemoteInfo(u.hostname, path[1], path[2].removesuffix(".git"))
+    repo = path[2]
+    try:
+        repo = repo.removesuffix(".git")  # type: ignore
+    except AttributeError:
+        # Py < 3.9
+        repo = repo[: -len(".git")] if repo and repo.endswith(".git") else repo
+
+    return GitRemoteInfo(u.hostname, path[1], repo)
 
 
-def get_cargo_version(p: Path) -> str:
+def parse_cargo_version(p: Path) -> str:
     """Extracts cargo version from a Cargo.toml file"""
     with p.open() as f:
         for line in f:
@@ -104,7 +113,10 @@ def get_cargo_version(p: Path) -> str:
     raise ValueError(f"No version found in {p}")
 
 
-def get_git_tag(fetch: bool = True) -> Optional[str]:
+def read_git_tag(fetch: bool = True) -> Optional[str]:
+    """Get local git tag for current repo
+
+    fetch: optionally fetch tags with depth of 1 from remote"""
     if fetch:
         check_call(["git", "fetch", "--tags", "--depth", "1"])
 
@@ -113,11 +125,12 @@ def get_git_tag(fetch: bool = True) -> Optional[str]:
 
 
 def read_version(from_tags: bool = False, fetch: bool = False) -> Optional[str]:
+    """Read version information from file or from git"""
     if from_tags:
-        return get_git_tag(fetch)
+        return read_git_tag(fetch)
 
     matchers = {
-        "Cargo.toml": get_cargo_version,
+        "Cargo.toml": parse_cargo_version,
     }
 
     for name, extractor in matchers.items():
@@ -133,7 +146,7 @@ def read_version(from_tags: bool = False, fetch: bool = False) -> Optional[str]:
 # Fetch release and assets from Github
 
 
-def get_release(
+def fetch_release(
     remote: GitRemoteInfo,
     version: Optional[str] = None
     # TODO: Accept an argument for pre-release
@@ -250,7 +263,11 @@ class PackageAdapter:
             self._package = ZipFile(BytesIO(response.content))
         elif content_type == "application/x-tar":
             self._package = TarFile(fileobj=response.raw)
-        elif content_type in ("application/gzip", "application/x-tar+gzip"):
+        elif content_type in (
+            "application/gzip",
+            "application/x-tar+gzip",
+            "application/x-compressed-tar",
+        ):
             self._package = TarFile.open(fileobj=BytesIO(response.content), mode="r:*")
         else:
             raise ValueError(f"Unknown or unsupported content type {content_type}")
@@ -295,6 +312,18 @@ def download_asset(
     extract_files: Optional[list[str]] = None,
     destination: Optional[Path] = None,
 ) -> list[Path]:
+    """Download asset from entity passed in
+
+    Extracts files from archives if provided. Any empty list will extract all files
+
+    Args
+        `asset`: asset dictionary as returned from API
+        `extract_files`: optional list of file paths to extract. An empty list will extract all
+        `destination`: destination directory to put the downloaded assset
+
+    Returns
+        list of Path objects containing all extracted files
+    """
     if destination is None:
         destination = Path.cwd()
 
@@ -358,7 +387,7 @@ class MapAddAction(argparse.Action):
         setattr(namespace, self.dest, dest)
 
 
-def parse_args(args: Optional[list[str]] = None) -> argparse.Namespace:
+def _parse_args(args: Optional[list[str]] = None) -> argparse.Namespace:
     parser = argparse.ArgumentParser()
     parser.add_argument(
         "format",
@@ -416,13 +445,15 @@ def parse_args(args: Optional[list[str]] = None) -> argparse.Namespace:
         help="Map a platform.machine() value to a custom value",
     )
     parser.add_argument(
-        "--exec", "-c", help="Shell commands to execute after download or extraction"
+        "--exec",
+        "-c",
+        help="Shell commands to execute after download or extraction. {} will be expanded to the downloaded asset name.",
     )
     parser.add_argument(
         "--extract-files",
         "-e",
         action="append",
-        help="A list of file name to extract from downloaded archive",
+        help="A list of file names to extract from downloaded archive",
     )
     parser.add_argument(
         "--extract-all",
@@ -440,7 +471,7 @@ def parse_args(args: Optional[list[str]] = None) -> argparse.Namespace:
 
     # Merge in fields from args and git remote
     if not all((parsed_args.owner, parsed_args.repo, parsed_args.hostname)):
-        remote_info = get_git_remote(parsed_args.git_url)
+        remote_info = parse_git_remote(parsed_args.git_url)
 
         def merge_field(a, b, field):
             value = getattr(a, field)
@@ -462,10 +493,37 @@ def parse_args(args: Optional[list[str]] = None) -> argparse.Namespace:
     return parsed_args
 
 
-def main():
-    args = parse_args()
+def download_release(
+    remote_info: GitRemoteInfo,
+    destination: Path,
+    format: str,
+    version: Optional[str] = None,
+    system_mapping: Optional[dict[str, str]] = None,
+    arch_mapping: Optional[dict[str, str]] = None,
+    extract_files: Optional[list[str]] = None,
+) -> list[Path]:
+    """Convenience method for fetching, downloading and extracting a release"""
+    release = fetch_release(remote_info)
+    asset = match_asset(
+        release,
+        format,
+        version=version,
+        system_mapping=system_mapping,
+        arch_mapping=arch_mapping,
+    )
+    files = download_asset(
+        asset,
+        extract_files=extract_files,
+        destination=destination,
+    )
 
-    release = get_release(
+    return files
+
+
+def main():
+    args = _parse_args()
+
+    release = fetch_release(
         GitRemoteInfo(args.hostname, args.owner, args.repo), args.version
     )
     asset = match_asset(
@@ -490,7 +548,7 @@ def main():
 
     # Optionally execute post command
     if args.exec:
-        check_call(args.exec, shell=True)
+        check_call(args.exec.format(asset["name"]), shell=True)
 
 
 if __name__ == "__main__":
